hepstats.hypotests.hypotests\_object module
===========================================

.. automodule:: hepstats.hypotests.hypotests_object
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
